@@ -2,6 +2,7 @@
 c          generic brems sampling routine
       implicit none
 #include "Zmedia.h"
+#include "ZepTrackp.h"
 
       record /epmedia/media  ! input.
       real*8 Ee            ! input. Electron/positron energy in GeV
@@ -22,9 +23,13 @@ c            complete screeing region
          call epBrCSampP(media, Ee, prob)
 
       else
+         if(LPMeffect ) then
 c            LPM region
-         call epBrHSampP(media, Ee, prob)
-
+            call epBrHSampP(media, Ee, prob)
+         else
+c           use  complete screeing
+            call epBrCSampP(media, Ee, prob)
+         endif
       endif
       call rndc(u)
       path = - log(u)/prob
@@ -33,7 +38,7 @@ c     ***********************************
       subroutine epBrSampE(media, Ee, Eg)
       implicit none
 #include "Zmedia.h"
-
+#include "ZepTrackp.h"
       record /epmedia/media  ! input.
       real*8 Ee            ! input. e-/e+ energy in GeV
       real*8 Eg            ! output. sampled Eg in GeV
@@ -53,8 +58,12 @@ c            complete screeing region
          call epBrCSampE(media, Ee, Eg)
 
       else
+         if(LPMeffect) then
 c            LPM region
-         call epBrHSampE(media, Ee, Eg)
-
+            call epBrHSampE(media, Ee, Eg)
+         else
+c             use complete screeing region
+            call epBrCSampE(media, Ee, Eg)
+         endif
       endif
       end
