@@ -30,6 +30,19 @@
       write(0,*) 
      *  ' number of events generated is ',nevent
  100  continue
+      write(0, *) ' projectile code,subcode,charge=',
+     *    pj.code, pj.subcode, pj.charge
+      write(0,*)
+     *   ' px, py,pz=', pj.fm.p(1),pj.fm.p(2),pj.fm.p(3)
+      write(0, *) ' target code,subcode,charge=',
+     *    tg.code, tg.subcode, tg.charge
+      write(0,*)
+     *   ' px, py,pz=', tg.fm.p(1),tg.fm.p(2),tg.fm.p(3)
+      write(0, '(a, 1pg12.3, a)') 
+     *  'Projectile energy at the targe rest system=',  
+     *   plab.fm.p(4), ' GeV(/particle) '
+      write(0, '(a, 1pg12.3,a)') '    and ', plab.fm.p(4)/pjmnum,
+     *  ' (GeV/nucleon); this must the value in dpmjet.inp '
       end
 
       subroutine init
@@ -63,12 +76,15 @@
       else
          nevent = abs( DestEventNo(2) )
       endif
+      outzero =0
+      check = 0
       call cmkSeed(InitRN(1), InitRN)
       call rnd1i(InitRN)        ! random number init.
       call cqUhookr(1, wzmin)
       call cqUhookr(2, wzmax)
       call cqUhookr(3, trackl)
-      call cqUhooki(1, outzero)
+      call cqUhooki(1, check)
+      call cqUhooki(2, outzero) 
 c       make projectile going +z
       call cqUhookc(1, input) 
       if(input(1:4) .eq. "file") then
@@ -126,7 +142,8 @@ c          once rewind to read successively for event generation
       endif
 
       write(0, *) 'Active int. model=',ActiveMdl
-      write(0, *) ' equiv. lab E=', plab.fm.p(4)
+      write(0, '(a, 1pg14.4, 0p, a)') ' equiv. total lab E=', 
+     *  plab.fm.p(4), ' GeV'
       if(xyz .eq. 0) then
          write(*, '(a)') '#  mulsubKEdir  user '
       else
@@ -180,23 +197,29 @@ c         form projectile  and target
       else
          pjmnum = pjsub
       endif
-      pj.fm.p(1) = pjpx*pjmnum
-      pj.fm.p(2) = pjpy*pjmnum
-      pj.fm.p(3) = pjpz*pjmnum
+c      pj.fm.p(1) = pjpx*pjmnum
+      pj.fm.p(1) = pjpx
+c      pj.fm.p(2) = pjpy*pjmnum
+      pj.fm.p(2) = pjpy
+c      pj.fm.p(3) = pjpz*pjmnum
+      pj.fm.p(3) = pjpz
       pj.fm.p(4) =
      *     sqrt(pj.fm.p(1)**2 + pj.fm.p(2)**2 + pj.fm.p(3)**2
      *     + pj.mass**2)
          
-c       make taget (rest of moving -z)
+c       make taget ( moving -z)
       call cmkptc(tgcode, tgsub, tgchg, tg)
       if(tgcode .ne. kgnuc) then
          tgmnum = 1
       else
          tgmnum = tgsub
       endif
-      tg.fm.p(1) = tgpx*tgmnum
-      tg.fm.p(2) = tgpy*tgmnum
-      tg.fm.p(3) = tgpz*tgmnum
+c      tg.fm.p(1) = tgpx*tgmnum
+      tg.fm.p(1) = tgpx
+c      tg.fm.p(2) = tgpy*tgmnum
+      tg.fm.p(2) = tgpy
+c      tg.fm.p(3) = tgpz*tgmnum
+      tg.fm.p(3) = tgpz
       tg.fm.p(4) =
      *     sqrt(tg.fm.p(1)**2 + tg.fm.p(2)**2 + tg.fm.p(3)**2 
      *   +   tg.mass**2)
@@ -212,10 +235,30 @@ c         by  general formula
       endif
       roots = sqrt(s)
       if(confirm .ne. 0) then
-         write(0, *) ' roots/2=', roots/2
+         write(0, '(a, 1pg12.3,a)') 'roots/2=', roots/2, 'GeV'
       endif
 cc           boost to target rest system
       call cbst1(1, tg, pj, plab)
+      if(confirm .ne. 0) then
+         write(0, *) ' projectile code,subcode,charge=',
+     *    pj.code, pj.subcode, pj.charge
+         write(0,*)
+     *   ' px, py,pz=', pj.fm.p(1),pj.fm.p(2),pj.fm.p(3)
+         write(0, *) ' target code,subcode,charge=',
+     *    tg.code, tg.subcode, tg.charge
+         write(0,*)
+     *   ' px, py,pz=', tg.fm.p(1),tg.fm.p(2),tg.fm.p(3)
+         write(0, '(a, 1pg12.3, a)') 
+     *  'Projectile energy at the targe rest system=',  
+     *   plab.fm.p(4), ' GeV(/particle) '
+         write(0, '(a, 1pg12.3,a)') '    and ', plab.fm.p(4)/pjmnum,
+     *  ' (GeV/nucleon); this must be given in dpmjet.inp '
+        if(check .ne. 0 ) then
+           write(0, *) 'Since you gave nonzero for the first UserHooki,'
+           write(0, *) 'I stop here; make it zero to go furhter'
+           stop
+        endif
+      endif
       end
 c     ************************
       subroutine outresul(a, ntp)
@@ -243,11 +286,11 @@ c     ************************
          wy = a(i).fm.p(2)/p               
          wz = a(i).fm.p(3)/p               
          if(xyz .eq. 0) then
-            write(*,'(3i3,g14.5,3f17.13, i5)')
+            write(*,'(3i3,g14.5,3f17.13, i7)')
      *        a(i).code, a(i).subcode, a(i).charge,
      *        a(i).fm.p(4)-a(i).mass, wx, wy, wz, j
          else
-            write(*,'(3i3,g14.5,1p3E11.3,0p3f17.13, i5)')
+            write(*,'(3i3,g14.5,1p3E11.3,0p3f17.13, i7)')
      *        a(i).code, a(i).subcode, a(i).charge,
      *        a(i).fm.p(4)-a(i).mass, xpos, ypos, zpos, 
      *        wx, wy, wz, j
@@ -316,7 +359,7 @@ c               boost to  target mooving system
       integer ntp0 ! input. number of ptcls. in a
       integer ntp  ! output. could be the same as ntp0
       integer j 
-      integer  i
+      integer  i, icon
       real*8 p, wz
       j = 0
       do i = 1, ntp0
@@ -325,12 +368,29 @@ c               boost to  target mooving system
          p = sqrt(p)
          wz = a(i).fm.p(3)/p 
          if( wz .ge. wzmin .and. wz .le. wzmax ) then
-            j = j + 1
-            a(j)=a(i)
+            call othercut(a(i), p, icon)
+            if(icon .eq. 0) then
+               j = j + 1
+               a(j)=a(i)
+            endif
          endif
       enddo
       ntp = j
       end
+      subroutine othercut(a, p, icon)
+      implicit none
+#include  "Zptcl.h"
+#include  "Zcode.h"
+#include  "Zevhnv.h"
+#include  "Zevhnp.h"
+#include  "Zmanagerp.h"
+      include "Zprivate.h"
+      record /ptcl/  a
+      real*8 p
+      integer icon
+      icon = 0
+      end
+
       subroutine sortbyke(a, ntp)
       implicit none
 #include  "Zptcl.h"
