@@ -14,9 +14,6 @@ c
             integer mediadirc, hookcc, hookic, hookrc
             
             mediadirc = 0 
-            hookcc = 0
-            hookic = 0
-            hookrc = 0
 
             call copenf(iowk, dsn, icon)
             if(icon .ne. 0) then
@@ -66,7 +63,9 @@ c            read baisc parameters; find separater
                elseif( vname .eq. 'Tmin') then
                   call arprmr(vvalue, Tmin)
                elseif( vname .eq. 'Trace') then
-                  call arprml(vvalue, Trace)
+                  if(.not. Trace) then
+                     call arprml(vvalue, Trace)
+                  endif
                elseif( vname .eq. 'TimeStruc') then
                   call arprml(vvalue, TimeStruc)
                elseif( vname .eq. 'MagField' ) then
@@ -123,8 +122,14 @@ c            read baisc parameters; find separater
                elseif( vname .eq. 'LPMeffect' ) then
                   call arprml(vvalue, LPMeffect)                 
                elseif( vname .eq. 'epHooks') then
-                  call arprmc(vvalue,  msg)
-                  read(msg, *)  epHooks
+                  if(epHooks(1) .eq. 0 .and. epHooks(2) .eq. 0 .and. 
+     *               epHooks(3) .eq. 0 )  then
+                     hookcc = 0
+                     hookic = 0
+                     hookrc = 0
+                     call arprmc(vvalue,  msg)
+                     read(msg, *)  epHooks
+                  endif
                elseif( vname .eq. 'epHookc') then
                   hookcc = hookcc + 1
                   if(hookcc .gt. epHooks(1)) then
